@@ -4,6 +4,7 @@ import os
 import re
 
 from flake8.main import application
+from flake8.options import config
 
 import py
 
@@ -188,11 +189,23 @@ def check_file(path, flake8ignore, maxlength, maxcomplexity,
     if statistics:
         args += ['--statistics']
     app = application.Application()
-    app.parse_preliminary_options_and_args(args)
-    app.make_config_finder()
-    app.find_plugins()
-    app.register_plugin_options()
-    app.parse_configuration_and_cli(args)
+    if not hasattr(app, 'parse_preliminary_options_and_args'):  # flake8 >= 3.8
+        prelim_opts, remaining_args = app.parse_preliminary_options(args)
+        config_finder = config.ConfigFileFinder(
+            app.program,
+            prelim_opts.append_config,
+            config_file=prelim_opts.config,
+            ignore_config_files=prelim_opts.isolated,
+        )
+        app.find_plugins(config_finder)
+        app.register_plugin_options()
+        app.parse_configuration_and_cli(config_finder, remaining_args)
+    else:
+        app.parse_preliminary_options_and_args(args)
+        app.make_config_finder()
+        app.find_plugins()
+        app.register_plugin_options()
+        app.parse_configuration_and_cli(args)
     if flake8ignore:
         app.options.ignore = flake8ignore
     app.make_formatter()  # fix this
@@ -204,7 +217,5 @@ def check_file(path, flake8ignore, maxlength, maxcomplexity,
     app.run_checks([str(path)])
     app.formatter.start()
     app.report_errors()
-    # app.report_statistics()
-    # app.report_benchmarks()
     app.formatter.stop()
     return app.result_count
